@@ -24,6 +24,7 @@
 #include "gitg-runner.h"
 #include "gitg-utils.h"
 #include "gitg-changed-file.h"
+#include "gitg-config.h"
 
 #include <string.h>
 
@@ -53,7 +54,7 @@ struct _GitgCommitPrivate
 
 	guint update_id;
 	guint end_id;
-	
+
 	GHashTable *files;
 };
 
@@ -96,10 +97,10 @@ static void
 gitg_commit_finalize(GObject *object)
 {
 	GitgCommit *commit = GITG_COMMIT(object);
-	
+
 	runner_cancel(commit);
 	g_object_unref(commit->priv->runner);
-	
+
 	g_hash_table_destroy(commit->priv->files);
 
 	G_OBJECT_CLASS(gitg_commit_parent_class)->finalize(object);
@@ -109,7 +110,7 @@ static void
 gitg_commit_dispose(GObject *object)
 {
 	GitgCommit *self = GITG_COMMIT(object);
-	
+
 	if (self->priv->repository)
 	{
 		g_signal_handlers_disconnect_by_func(self->priv->repository, G_CALLBACK(gitg_commit_refresh), self);
@@ -139,7 +140,7 @@ static void
 gitg_commit_set_property(GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
 	GitgCommit *self = GITG_COMMIT(object);
-	
+
 	switch (prop_id)
 	{
 		case PROP_REPOSITORY:
@@ -164,7 +165,7 @@ gitg_commit_class_init(GitgCommitClass *klass)
 
 	object_class->dispose = gitg_commit_dispose;
 	object_class->finalize = gitg_commit_finalize;
-	
+
 	object_class->set_property = gitg_commit_set_property;
 	object_class->get_property = gitg_commit_get_property;
 
@@ -204,7 +205,7 @@ static void
 gitg_commit_init(GitgCommit *self)
 {
 	self->priv = GITG_COMMIT_GET_PRIVATE(self);
-	
+
 	self->priv->runner = gitg_runner_new(10000);
 	self->priv->files = g_hash_table_new_full(g_file_hash, (GEqualFunc)g_file_equal, (GDestroyNotify)g_object_unref, (GDestroyNotify)g_object_unref);
 }
@@ -223,7 +224,7 @@ runner_connect(GitgCommit *commit, GCallback updatefunc, GCallback endfunc)
 		g_signal_handler_disconnect(commit->priv->runner, commit->priv->update_id);
 		commit->priv->update_id = 0;
 	}
-	
+
 	if (commit->priv->end_id)
 	{
 		g_signal_handler_disconnect(commit->priv->runner, commit->priv->end_id);
@@ -232,7 +233,7 @@ runner_connect(GitgCommit *commit, GCallback updatefunc, GCallback endfunc)
 
 	if (updatefunc)
 		commit->priv->update_id = g_signal_connect(commit->priv->runner, "update", updatefunc, commit);
-	
+
 	if (endfunc)
 		commit->priv->end_id = g_signal_connect(commit->priv->runner, "end-loading", endfunc, commit);
 }
@@ -241,14 +242,14 @@ static void
 update_changed_file_status(GitgChangedFile *file, char const *action, gchar const *mode)
 {
 	GitgChangedFileStatus status;
-	
+
 	if (strcmp(action, "D") == 0)
 		status = GITG_CHANGED_FILE_STATUS_DELETED;
 	else if (strcmp(mode, "000000") == 0)
 		status = GITG_CHANGED_FILE_STATUS_NEW;
 	else
 		status = GITG_CHANGED_FILE_STATUS_MODIFIED;
-	
+
 	gitg_changed_file_set_status(file, status);
 }
 
@@ -256,58 +257,58 @@ static void
 add_files(GitgCommit *commit, gchar **buffer, gboolean cached)
 {
 	gchar *line;
-	
+
 	while ((line = *buffer++) != NULL)
 	{
 		gchar **parts = g_strsplit_set(line, " \t", 0);
 		guint len = g_strv_length(parts);
-		
+
 		if (len < 6)
 		{
 			g_warning("Invalid line: %s (%d)", line, len);
 			g_strfreev(parts);
 			continue;
 		}
-		
+
 		gchar const *mode = parts[0] + 1;
 		gchar const *sha = parts[2];
-		
+
 		gchar *path = g_build_filename(gitg_repository_get_path(commit->priv->repository), parts[5], NULL);
-		
+
 		GFile *file = g_file_new_for_path(path);
 		g_free(path);
 
 		GitgChangedFile *f = GITG_CHANGED_FILE(g_hash_table_lookup(commit->priv->files, file));
-		
+
 		if (f)
 		{
 			GitgChangedFileChanges changes = gitg_changed_file_get_changes(f);
 
 			g_object_set_data(G_OBJECT(f), CAN_DELETE_KEY, NULL);
 			update_changed_file_status(f, parts[4], mode);
-			
+
 			if (cached)
 			{
 				gitg_changed_file_set_sha(f, sha);
 				gitg_changed_file_set_mode(f, mode);
-				
+
 				changes |= GITG_CHANGED_FILE_CHANGES_CACHED;
 			}
 			else
 			{
 				changes |= GITG_CHANGED_FILE_CHANGES_UNSTAGED;
 			}
-			
+
 			gitg_changed_file_set_changes(f, changes);
-			
+
 			if ((changes & GITG_CHANGED_FILE_CHANGES_CACHED) && (changes & GITG_CHANGED_FILE_CHANGES_UNSTAGED))
 				gitg_changed_file_set_status(f, GITG_CHANGED_FILE_STATUS_MODIFIED);
-			
+
 			g_object_unref(file);
 			g_strfreev(parts);
 			continue;
 		}
-		
+
 		f = gitg_changed_file_new(file);
 		update_changed_file_status(f, parts[4], mode);
 
@@ -315,12 +316,12 @@ add_files(GitgCommit *commit, gchar **buffer, gboolean cached)
 		gitg_changed_file_set_mode(f, mode);
 
 		GitgChangedFileChanges changes;
-		
+
 		changes = cached ? GITG_CHANGED_FILE_CHANGES_CACHED : GITG_CHANGED_FILE_CHANGES_UNSTAGED;
 		gitg_changed_file_set_changes(f, changes);
-		
+
 		g_hash_table_insert(commit->priv->files, file, f);
-		
+
 		g_signal_connect(f, "changed", G_CALLBACK(on_changed_file_changed), commit);
 		g_signal_emit(commit, commit_signals[INSERTED], 0, f);
 
@@ -339,7 +340,7 @@ delete_file(GFile *key, GitgChangedFile *value, GitgCommit *commit)
 {
 	if (!g_object_get_data(G_OBJECT(value), CAN_DELETE_KEY))
 		return FALSE;
-	
+
 	g_signal_emit(commit, commit_signals[REMOVED], 0, value);
 	return TRUE;
 }
@@ -356,7 +357,7 @@ read_unstaged_files_end(GitgRunner *runner, gboolean cancelled, GitgCommit *comm
 	gchar *head = gitg_repository_parse_head(commit->priv->repository);
 	gitg_runner_cancel(runner);
 
-	runner_connect(commit, G_CALLBACK(read_cached_files_update), G_CALLBACK(refresh_done));	
+	runner_connect(commit, G_CALLBACK(read_cached_files_update), G_CALLBACK(refresh_done));
 	gitg_repository_run_commandv(commit->priv->repository, commit->priv->runner, NULL, "diff-index", "--cached", head, NULL);
 	g_free(head);
 }
@@ -371,7 +372,7 @@ static void
 read_other_files_end(GitgRunner *runner, gboolean cancelled, GitgCommit *commit)
 {
 	gitg_runner_cancel(runner);
-	
+
 	runner_connect(commit, G_CALLBACK(read_unstaged_files_update), G_CALLBACK(read_unstaged_files_end));
 	gitg_repository_run_commandv(commit->priv->repository,commit->priv->runner, NULL, "diff-files", NULL);
 }
@@ -381,7 +382,7 @@ changed_file_new(GitgChangedFile *f)
 {
 	gitg_changed_file_set_status(f, GITG_CHANGED_FILE_STATUS_NEW);
 	gitg_changed_file_set_changes(f, GITG_CHANGED_FILE_CHANGES_UNSTAGED);
-	
+
 	g_object_set_data(G_OBJECT(f), CAN_DELETE_KEY, NULL);
 }
 
@@ -395,26 +396,26 @@ read_other_files_update(GitgRunner *runner, gchar **buffer, GitgCommit *commit)
 		/* Skip empty lines */
 		if (!*line)
 			continue;
-			
+
 		/* Check if file is already in our index */
 		gchar *path = g_build_filename(gitg_repository_get_path(commit->priv->repository), line, NULL);
-		
+
 		GFile *file = g_file_new_for_path(path);
 		g_free(path);
 		GitgChangedFile *f = g_hash_table_lookup(commit->priv->files, file);
-		
+
 		if (f)
 		{
 			changed_file_new(f);
 			g_object_unref(file);
 			continue;
 		}
-		
+
 		f = gitg_changed_file_new(file);
 
-		changed_file_new(f);		
+		changed_file_new(f);
 		g_hash_table_insert(commit->priv->files, file, f);
-		
+
 		g_signal_emit(commit, commit_signals[INSERTED], 0, f);
 	}
 }
@@ -424,7 +425,7 @@ update_index_end(GitgRunner *runner, gboolean cancelled, GitgCommit *commit)
 {
 	gitg_runner_cancel(runner);
 	runner_connect(commit, G_CALLBACK(read_other_files_update), G_CALLBACK(read_other_files_end));
-	
+
 	gitg_repository_run_commandv(commit->priv->repository, commit->priv->runner, NULL, "ls-files", "--others", "--exclude-standard", NULL);
 }
 
@@ -448,7 +449,7 @@ gitg_commit_refresh(GitgCommit *commit)
 	g_return_if_fail(GITG_IS_COMMIT(commit));
 
 	runner_cancel(commit);
-	
+
 	g_hash_table_foreach(commit->priv->files, (GHFunc)set_can_delete, commit);
 
 	/* Read other files */
@@ -466,22 +467,22 @@ update_index_staged(GitgCommit *commit, GitgChangedFile *file)
 	gchar *head = gitg_repository_parse_head(commit->priv->repository);
 
 	gchar **ret = gitg_repository_command_with_outputv(commit->priv->repository, NULL, "diff-index", "--cached", head, "--", path, NULL);
-	
+
 	g_free(path);
 	g_free(head);
 	g_object_unref(f);
-	
+
 	if (!ret)
 		return;
-	
+
 	gchar **parts = *ret ? g_strsplit_set(*ret, " \t", 0) : NULL;
 	g_strfreev(ret);
-	
+
 	if (parts && g_strv_length(parts) > 2)
 	{
 		gitg_changed_file_set_mode(file, parts[0] + 1);
 		gitg_changed_file_set_sha(file, parts[2]);
-		
+
 		gitg_changed_file_set_changes(file, gitg_changed_file_get_changes(file) | GITG_CHANGED_FILE_CHANGES_CACHED);
 		update_changed_file_status(file, parts[4], parts[0] + 1);
 	}
@@ -489,7 +490,7 @@ update_index_staged(GitgCommit *commit, GitgChangedFile *file)
 	{
 		gitg_changed_file_set_changes(file, gitg_changed_file_get_changes(file) & ~GITG_CHANGED_FILE_CHANGES_CACHED);
 	}
-	
+
 	if (parts)
 		g_strfreev(parts);
 }
@@ -502,7 +503,7 @@ update_index_unstaged(GitgCommit *commit, GitgChangedFile *file)
 	gchar **ret = gitg_repository_command_with_outputv(commit->priv->repository, NULL, "diff-files", "--", path, NULL);
 	g_free(path);
 	g_object_unref(f);
-	
+
 	if (ret && *ret)
 	{
 		gitg_changed_file_set_changes(file, gitg_changed_file_get_changes(file) | GITG_CHANGED_FILE_CHANGES_UNSTAGED);
@@ -511,7 +512,7 @@ update_index_unstaged(GitgCommit *commit, GitgChangedFile *file)
 	{
 		gitg_changed_file_set_changes(file, gitg_changed_file_get_changes(file) & ~GITG_CHANGED_FILE_CHANGES_UNSTAGED);
 	}
-	
+
 	if (ret)
 		g_strfreev(ret);
 }
@@ -525,7 +526,7 @@ update_index_file(GitgCommit *commit, GitgChangedFile *file)
 	g_object_unref(f);
 
 	gitg_repository_commandv(commit->priv->repository, NULL, "update-index", "-q", "--unmerged", "--ignore-missing", "--refresh", NULL);
-	
+
 	g_free(path);
 }
 
@@ -538,7 +539,7 @@ refresh_changes(GitgCommit *commit, GitgChangedFile *file)
 	/* Determine if it still has staged/unstaged changes */
 	update_index_staged(commit, file);
 	update_index_unstaged(commit, file);
-	
+
 	GitgChangedFileChanges changes = gitg_changed_file_get_changes(file);
 	GitgChangedFileStatus status = gitg_changed_file_get_status(file);
 
@@ -546,7 +547,7 @@ refresh_changes(GitgCommit *commit, GitgChangedFile *file)
 		gitg_changed_file_set_status(file, GITG_CHANGED_FILE_STATUS_NEW);
 	else if ((changes & GITG_CHANGED_FILE_CHANGES_CACHED) && (changes & GITG_CHANGED_FILE_CHANGES_UNSTAGED))
 		gitg_changed_file_set_status(file, GITG_CHANGED_FILE_STATUS_MODIFIED);
-	
+
 	if (status == GITG_CHANGED_FILE_STATUS_NEW &&
 	    !(changes & GITG_CHANGED_FILE_CHANGES_CACHED))
 	{
@@ -559,14 +560,14 @@ apply_hunk(GitgCommit *commit, GitgChangedFile *file, gchar const *hunk, gboolea
 {
 	g_return_val_if_fail(GITG_IS_COMMIT(commit), FALSE);
 	g_return_val_if_fail(GITG_IS_CHANGED_FILE(file), FALSE);
-	
+
 	g_return_val_if_fail(hunk != NULL, FALSE);
-	
+
 	gboolean ret = gitg_repository_command_with_inputv(commit->priv->repository, hunk, error, "apply", "--cached", reverse ? "--reverse" : NULL, NULL);
-	
+
 	if (ret)
 		refresh_changes(commit, file);
-	
+
 	return ret;
 }
 
@@ -575,15 +576,15 @@ gitg_commit_stage(GitgCommit *commit, GitgChangedFile *file, gchar const *hunk,
 {
 	if (hunk)
 		return apply_hunk(commit, file, hunk, FALSE, error);
-	
+
 	/* Otherwise, stage whole file */
 	GFile *f = gitg_changed_file_get_file(file);
 	gchar *path = gitg_repository_relative(commit->priv->repository, f);
 	g_object_unref(f);
-	
+
 	gboolean ret = gitg_repository_commandv(commit->priv->repository, NULL, "update-index", "--add", "--remove", "--", path, NULL);
 	g_free(path);
-	
+
 	if (ret)
 		refresh_changes(commit, file);
 	else
@@ -597,7 +598,7 @@ gitg_commit_unstage(GitgCommit *commit, GitgChangedFile *file, gchar const *hunk
 {
 	if (hunk)
 		return apply_hunk(commit, file, hunk, TRUE, error);
-	
+
 	/* Otherwise, unstage whole file */
 	GFile *f = gitg_changed_file_get_file(file);
 	gchar *path = gitg_repository_relative(commit->priv->repository, f);
@@ -606,12 +607,12 @@ gitg_commit_unstage(GitgCommit *commit, GitgChangedFile *file, gchar const *hunk
 	gchar *input = g_strdup_printf("%s %s\t%s\n", gitg_changed_file_get_mode(file), gitg_changed_file_get_sha(file), path);
 	gboolean ret = gitg_repository_command_with_inputv(commit->priv->repository, input, error, "update-index", "--index-info", NULL);
 	g_free(input);
-	
+
 	if (ret)
 		refresh_changes(commit, file);
 	else
 		g_error("Update index for unstage failed");
-	
+
 	return ret;
 }
 
@@ -620,7 +621,7 @@ find_staged(GFile *key, GitgChangedFile *value, gboolean *result)
 {
 	if (*result)
 		return;
-	
+
 	*result = (gitg_changed_file_get_changes(value) & GITG_CHANGED_FILE_CHANGES_CACHED);
 }
 
@@ -629,7 +630,7 @@ gitg_commit_has_changes(GitgCommit *commit)
 {
 	g_return_val_if_fail(GITG_IS_COMMIT(commit), FALSE);
 	gboolean result = FALSE;
-	
+
 	g_hash_table_foreach(commit->priv->files, (GHFunc)find_staged, &result);
 	return result;
 }
@@ -639,7 +640,7 @@ comment_parse_subject(gchar const *comment)
 {
 	gchar *ptr;
 	gchar *subject;
-	
+
 	if ((ptr = g_utf8_strchr(comment, g_utf8_strlen(comment, -1), '\n')) != NULL)
 	{
 		subject = g_strndup(comment, ptr - comment);
@@ -648,10 +649,10 @@ comment_parse_subject(gchar const *comment)
 	{
 		subject = g_strdup(comment);
 	}
-	
+
 	gchar *commit = g_strconcat("commit:", subject, NULL);
 	g_free(subject);
-	
+
 	return commit;
 }
 
@@ -660,16 +661,16 @@ write_tree(GitgCommit *commit, gchar **tree, GError **error)
 {
 	gchar const *argv[] = {"write-tree", NULL};
 	gchar **lines = gitg_repository_command_with_output(commit->priv->repository, argv, error);
-	
+
 	if (!lines || strlen(*lines) != HASH_SHA_SIZE)
 	{
 		g_strfreev(lines);
 		return FALSE;
 	}
-	
+
 	*tree = g_strdup(*lines);
 	g_strfreev(lines);
-	
+
 	return TRUE;
 }
 
@@ -677,36 +678,36 @@ static gchar *
 get_signed_off_line(GitgCommit *commit)
 {
 	gchar **user = gitg_repository_command_with_outputv(commit->priv->repository, NULL, "config", "--get", "user.name", NULL);
-	
+
 	if (!user)
 		return NULL;
-	
+
 	if (!*user || !**user)
 	{
 		g_strfreev(user);
 		return NULL;
 	}
-	
+
 	gchar **email = gitg_repository_command_with_outputv(commit->priv->repository, NULL, "config", "--get", "user.email", NULL);
-	
+
 	if (!email)
 	{
 		g_strfreev(user);
 		return NULL;
 	}
-	
+
 	if (!*email || !**email)
 	{
 		g_strfreev(user);
 		g_strfreev(email);
-		
+
 		return NULL;
 	}
-	
+
 	gchar *ret = g_strdup_printf("Signed-off-by: %s <%s>", *user, *email);
 	g_strfreev(user);
 	g_strfreev(email);
-	
+
 	return ret;
 }
 
@@ -719,7 +720,7 @@ on_commit_tree_update (GitgRunner *runner, gchar **lines, GString *buffer)
 		{
 			g_string_append_c (buffer, '\n');
 		}
-		
+
 		g_string_append (buffer, *lines);
 		++lines;
 	}
@@ -729,7 +730,7 @@ static void
 set_amend_environment (GitgCommit *commit, GitgRunner *runner)
 {
 	gchar **out;
-	
+
 	out = gitg_repository_command_with_outputv (commit->priv->repository,
 	                                            NULL,
 	                                            "cat-file",
@@ -745,7 +746,7 @@ set_amend_environment (GitgCommit *commit, GitgRunner *runner)
 
 	GMatchInfo *info = NULL;
 	gchar **ptr = out;
-	
+
 	while (ptr && *ptr)
 	{
 		if (g_regex_match (r, *ptr, 0, &info))
@@ -757,34 +758,75 @@ set_amend_environment (GitgCommit *commit, GitgRunner *runner)
 			gitg_runner_add_environment (runner, "GIT_AUTHOR_NAME", name);
 			gitg_runner_add_environment (runner, "GIT_AUTHOR_EMAIL", email);
 			gitg_runner_add_environment (runner, "GIT_AUTHOR_DATE", date);
-			
+
 			g_free (name);
 			g_free (email);
 			g_free (date);
-		
+
 			break;
 		}
-		
+
 		++ptr;
 	}
-	
+
 	g_strfreev (out);
 }
 
+static gchar *
+convert_commit_encoding (GitgCommit *commit, gchar const *s)
+{
+	GitgConfig *config;
+	gchar *encoding;
+	gchar *ret;
+
+	config = gitg_config_new (commit->priv->repository);
+	encoding = gitg_config_get_value (config, "i18n.commitencoding");
+
+	if (!encoding || !*encoding)
+	{
+		g_object_unref (config);
+		g_free (encoding);
+
+		config = gitg_config_new (NULL);
+
+		encoding = gitg_config_get_value (config, "i18n.commitencoding");
+	}
+
+	g_object_unref (config);
+
+	if (!encoding || !*encoding || g_ascii_strcasecmp (encoding, "UTF-8") == 0)
+	{
+		g_free (encoding);
+		return g_strdup (s);
+	}
+
+	// Try to convert from UTF-8 to 'encoding'
+	ret = g_convert (s, -1, encoding, "UTF-8", NULL, NULL, NULL);
+
+	if (!ret)
+	{
+		// Just use 's' then, even if it is UTF-8...
+		ret = g_strdup (s);
+	}
+
+	g_free (encoding);
+	return ret;
+}
+
 static gboolean 
 commit_tree(GitgCommit *commit, gchar const *tree, gchar const *comment, gboolean signoff, gboolean amend, gchar **ref, GError **error)
 {
 	gchar *fullcomment;
-	
+
 	if (signoff)
 	{
 		gchar *line = get_signed_off_line(commit);
-		
+
 		if (!line)
 		{
 			if (error)
 				g_set_error(error, GITG_COMMIT_ERROR, GITG_COMMIT_ERROR_SIGNOFF, "Could not retrieve user name or email for signoff message");
-			
+
 			return FALSE;
 		}
 
@@ -794,9 +836,9 @@ commit_tree(GitgCommit *commit, gchar const *tree, gchar const *comment, gboolea
 	{
 		fullcomment = g_strdup(comment);
 	}
-	
+
 	gchar *head;
-	
+
 	if (amend)
 	{
 		head = gitg_repository_parse_ref(commit->priv->repository, "HEAD^");
@@ -805,19 +847,21 @@ commit_tree(GitgCommit *commit, gchar const *tree, gchar const *comment, gboolea
 	{
 		head = gitg_repository_parse_ref(commit->priv->repository, "HEAD");
 	}
-	
+
 	GitgRunner *runner = gitg_runner_new_synchronized (1000);
 	GString *buffer = g_string_new ("");
-	
+
 	if (amend)
 	{
 		set_amend_environment (commit, runner);
 	}
-	
+
+	gchar *converted = convert_commit_encoding (commit, fullcomment);
+
 	g_signal_connect (runner, "update", G_CALLBACK (on_commit_tree_update), buffer);
 	gitg_repository_run_command_with_inputv (commit->priv->repository,
 	                                         runner,
-	                                         fullcomment,
+	                                         converted,
 	                                         error,
 	                                         "commit-tree",
 	                                         tree,
@@ -827,6 +871,7 @@ commit_tree(GitgCommit *commit, gchar const *tree, gchar const *comment, gboolea
 
 	g_free(head);
 	g_free(fullcomment);
+	g_free(converted);
 	g_object_unref (runner);
 
 	if (buffer->len != HASH_SHA_SIZE)
@@ -834,7 +879,7 @@ commit_tree(GitgCommit *commit, gchar const *tree, gchar const *comment, gboolea
 		g_string_free(buffer, TRUE);
 		return FALSE;
 	}
-	
+
 	*ref = g_string_free (buffer, FALSE);
 	return TRUE;
 }
@@ -842,41 +887,46 @@ commit_tree(GitgCommit *commit, gchar const *tree, gchar const *comment, gboolea
 static gboolean
 update_ref(GitgCommit *commit, gchar const *ref, gchar const *subject, GError **error)
 {
-	gchar const *argv[] = {"update-ref", "-m", subject, "HEAD", ref, NULL};
-	return gitg_repository_command(commit->priv->repository, argv, error);
+	gchar *converted = convert_commit_encoding (commit, subject);
+	gchar const *argv[] = {"update-ref", "-m", converted, "HEAD", ref, NULL};
+
+	gboolean ret = gitg_repository_command(commit->priv->repository, argv, error);
+	g_free (converted);
+
+	return ret;
 }
 
 gboolean
 gitg_commit_commit(GitgCommit *commit, gchar const *comment, gboolean signoff, gboolean amend, GError **error)
 {
 	g_return_val_if_fail(GITG_IS_COMMIT(commit), FALSE);
-	
+
 	gchar *tree;
 
 	if (!write_tree(commit, &tree, error))
 		return FALSE;
-	
+
 	gchar *path = g_build_filename (gitg_repository_get_path (commit->priv->repository),
 	                                ".git",
 	                                "COMMIT_EDITMSG",
 	                                NULL);
 	g_file_set_contents (path, comment, -1, NULL);\
 	g_free (path);
-	
+
 	gchar *ref;
 	gboolean ret = commit_tree(commit, tree, comment, signoff, amend, &ref, error);
 	g_free(tree);
-	
+
 	if (!ret)
 		return FALSE;
 
 	gchar *subject = comment_parse_subject(comment);
 	ret = update_ref(commit, ref, subject, error);
 	g_free(subject);
-	
+
 	if (!ret)
 		return FALSE;
-	
+
 	gitg_repository_reload(commit->priv->repository);
 	return TRUE;
 }
@@ -896,16 +946,16 @@ gboolean
 gitg_commit_revert(GitgCommit *commit, GitgChangedFile *file, gchar const *hunk, GError **error)
 {
 	gboolean ret;
-	
+
 	if (!hunk)
 	{
 		GFile *f = gitg_changed_file_get_file(file);
 		gchar *path = gitg_repository_relative(commit->priv->repository, f);
-	
+
 		ret = gitg_repository_command_with_inputv(commit->priv->repository, path, error, "checkout-index", "--index", "--quiet", "--force", "--stdin", NULL);
-		
+
 		g_free(path);
-		
+
 		update_index_file(commit, file);
 		update_index_unstaged(commit, file);
 		g_object_unref(f);
@@ -914,15 +964,15 @@ gitg_commit_revert(GitgCommit *commit, GitgChangedFile *file, gchar const *hunk,
 	{
 		GitgRunner *runner = gitg_runner_new_synchronized(1000);
 		gchar const *argv[] = {"patch", "-p1", "-R", NULL};
-		
+
 		ret = gitg_runner_run_with_arguments(runner, argv, gitg_repository_get_path(commit->priv->repository), hunk, NULL); 
-	
+
 		update_index_file(commit, file);
 		update_index_unstaged(commit, file);
-		
+
 		g_object_unref(runner);
 	}
-	
+
 	return ret;
 }
 
@@ -931,16 +981,16 @@ gitg_commit_add_ignore(GitgCommit *commit, GitgChangedFile *file, GError **error
 {
 	g_return_val_if_fail(GITG_IS_COMMIT(commit), FALSE);
 	g_return_val_if_fail(GITG_IS_CHANGED_FILE(file), FALSE);
-	
+
 	GFile *f = gitg_changed_file_get_file(file);
 	gchar *path = gitg_repository_relative(commit->priv->repository, f);
-	
+
 	gchar *ignore = g_strdup_printf("%s/.gitignore", gitg_repository_get_path(commit->priv->repository));
 	GFile *ig = g_file_new_for_path(ignore);
-	
+
 	GFileOutputStream *stream = g_file_append_to(ig, G_FILE_CREATE_NONE, NULL, error);
 	gboolean ret = FALSE;
-	
+
 	if (stream)
 	{
 		gchar *line = g_strdup_printf("/%s\n", path);
@@ -950,11 +1000,11 @@ gitg_commit_add_ignore(GitgCommit *commit, GitgChangedFile *file, GError **error
 		g_object_unref(stream);
 		g_free(line);
 	}
-	
+
 	if (ret)
 		remove_file(commit, file);
 
-	g_object_unref(f);	
+	g_object_unref(f);
 	g_free(ignore);
 	g_free(path);
 
@@ -972,9 +1022,9 @@ gitg_commit_find_changed_file(GitgCommit *commit, GFile *file)
 {
 	g_return_val_if_fail(GITG_IS_COMMIT(commit), NULL);
 	g_return_val_if_fail(G_IS_FILE(file), NULL);
-	
+
 	GitgChangedFile *f = g_hash_table_lookup(commit->priv->files, file);
-	
+
 	if (f != NULL)
 	{
 		return g_object_ref(f);
@@ -989,9 +1039,9 @@ gchar *
 gitg_commit_amend_message (GitgCommit *commit)
 {
 	g_return_val_if_fail (GITG_IS_COMMIT (commit), NULL);
-	
+
 	gchar **out;
-	
+
 	out = gitg_repository_command_with_outputv (commit->priv->repository,
 	                                            NULL,
 	                                            "cat-file",
@@ -1000,11 +1050,11 @@ gitg_commit_amend_message (GitgCommit *commit)
 	                                            NULL);
 
 	gchar *ret = NULL;
-	
+
 	if (out)
 	{
 		gchar **ptr = out;
-		
+
 		while (*ptr)
 		{
 			if (!**ptr)
@@ -1012,29 +1062,29 @@ gitg_commit_amend_message (GitgCommit *commit)
 				++ptr;
 				break;
 			}
-			
+
 			++ptr;
 		}
-		
+
 		if (*ptr && **ptr)
 		{
 			GString *buffer = g_string_new ("");
-			
+
 			while (*ptr)
 			{
 				if (buffer->len != 0)
 				{
 					g_string_append_c (buffer, '\n');
 				}
-				
+
 				g_string_append (buffer, *ptr);
 				++ptr;
 			}
-			
+
 			ret = g_string_free (buffer, FALSE);
 		}
 	}
-	
+
 	g_strfreev (out);
 	return ret;
 }
